"""This is Bob - The blob.
Bob can talk!
I love Bob!"""

bobsayTemplate = r'''
       /-{line}-\
       | {text} |
     - \-{line}-/
/~~~~~~~~~\
|   O O   |
|    ~    |
\~~~~~~~~~/
'''


def bobsay(text: str = 'Hi! Im Bob!'):
	r"""Bob talks."""
	if text:
		line = "-" * len(text)
		print(bobsayTemplate.format(line=line, text=text))
